==> lxqt-panel_2.2.2.orig.tar.xz: lxqt-panel-2.2.2/plugin-spacer/translations/spacer_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>SpacerConfiguration</name>
    <message>
        <location filename="../spacerconfiguration.ui" line="14"/>
        <source>Spacer Settings</source>
        <translation>Definições do espaçador</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="20"/>
        <source>Space width:</source>
        <translation>Largura do espaço:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="54"/>
        <source>Space type:</source>
        <translation>Tipo de espaço:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="27"/>
        <source>fixed</source>
        <translation>fixo</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="47"/>
        <source>expandable</source>
        <translation>expansível</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="34"/>
        <source>lined</source>
        <translation>linha</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="35"/>
        <source>dotted</source>
        <translation>pontilhado</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="36"/>
        <source>invisible</source>
        <translation>invisível</translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.3.2.orig.tar.xz: lxqt-panel-2.3.2/plugin-spacer/translations/spacer_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>SpacerConfiguration</name>
    <message>
        <location filename="../spacerconfiguration.ui" line="14"/>
        <source>Spacer Settings</source>
        <translation>Configurações do espaçador</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="20"/>
        <source>Space width:</source>
        <translation>Largura do espaço:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="54"/>
        <source>Space type:</source>
        <translation>Tipo de espaço:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="27"/>
        <source>fixed</source>
        <translation>fixo</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="47"/>
        <source>expandable</source>
        <translation>expansível</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="34"/>
        <source>lined</source>
        <translation>linha</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="35"/>
        <source>dotted</source>
        <translation>pontilhado</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="36"/>
        <source>invisible</source>
        <translation>invisível</translation>
    </message>
</context>
</TS>
